==> cv-react-library-0.1.20.tgz: package/src/components/native/LineChart/LineChart.js <==
import React from 'react';
import PropTypes from 'prop-types';
import ChartWrapper from '../ChartWrapper/ChartWrapper';

// Import styles
import getStyles from './LineChart.styles';

/**
 * A line chart displays information as a series of data points called 'markers' connected by straight line segments.
 * @see https://echarts.apache.org/examples/en/editor.html?c=line-simple
 */
const LineChart = (props) => {
    const {
        animation,
        contextStyles,
        gridLines,
        horizontalGridLines,
        legendText,
        maxX,
        maxY,
        minX,
        minY,
        onPress,
        seriesData,
        testID,
        title,
        tooltip,
        verticalGridLines,
        xAxis,
        xAxisTitle,
        yAxis,
        yAxisTitle,
        zoom,
    } = props;

    const styles = getStyles(contextStyles);

    /** Build axis options */
    const axisOptions = {
        xAxis: {
            axisTick: {
                // Move the tick from between the bars to the center of each bar
                alignWithLabel: true,
            },
            data: [],
            show: xAxis,
            splitLine: {
                // Show vertical grid lines
                show: gridLines && verticalGridLines,
            },
            type: 'category',
        },
        yAxis: {
            show: yAxis,
            splitLine: {
                // Show horizontal grid lines
                show: gridLines && horizontalGridLines,
            },
            type: 'value',
        },
    };

    // Set axis titles
    if (xAxisTitle) {
        axisOptions.xAxis.name = xAxisTitle;
        axisOptions.xAxis.nameLocation = 'center';
        axisOptions.xAxis.nameGap = 25;
    }
    if (yAxisTitle) {
        axisOptions.yAxis.name = yAxisTitle;
        axisOptions.yAxis.nameLocation = 'center';
        axisOptions.yAxis.nameGap = 30;
    }

    /** Build chart options */
    const chartOptions = {
        animation,
        backgroundColor: 'transparent',
        grid: {
            containLabel: true,
            show: true,
        },
        xAxis: axisOptions.xAxis,
        yAxis: axisOptions.yAxis,
    };

    // Set chart title
    if (title) {
        chartOptions.title = {
            text: title,
        };
    }

    // Enable tooltip
    if (tooltip) {
        chartOptions.tooltip = {
            confine: true,
        };
    }

    // Set chart legend
    if (legendText) { chartOptions.legend = { data: legendText }; }

    // Map series data prop to chart data structure
    const mappedChartData = seriesData.map((lineDataSeries) => (
        lineDataSeries.map((item) => {
            // Build bar labels array
            if (!axisOptions.xAxis.data.find((label) => (label === item.axisLabel))) {
                axisOptions.xAxis.data.push(item.axisLabel);
            }

            // Begin minimum line detail
            const lineDetail = {
                itemStyle: {},
                lineStyle: {},
                name: item.axisLabel,
                value: item.value,
            };

            // Add styles for line
            if (item.color) {
                lineDetail.lineStyle.color = item.color;
            }
            if (item.width || item.width === 0) {
                lineDetail.lineStyle.width = item.width;
            }
            if (item.opacity || item.opacity === 0) {
                lineDetail.lineStyle.opacity = item.opacity;
            }

            // Add styles for circular points
            if (item.symbolColor) {
                lineDetail.itemStyle.color = item.symbolColor;
            }
            if (item.symbolEmphasisColor) {
                lineDetail.itemStyle.emphasis = { color: item.symbolEmphasisColor };
            }
            if (item.symbolSize || item.symbolSize === 0) {
                lineDetail.symbolSize = item.symbolSize;
            }

            return lineDetail;
        })
    ));

    // Set range parameters
    if (maxX || maxX === 0) { chartOptions.xAxis.max = maxX; }
    if (minX || minX === 0) { chartOptions.xAxis.min = minX; }
    if (maxX || minX) { chartOptions.xAxis.scale = true; }
    if (maxY || maxY === 0) { chartOptions.yAxis.max = maxY; }
    if (minY || minY === 0) { chartOptions.yAxis.min = minY; }
    if (maxY || minY) { chartOptions.yAxis.scale = true; }

    /** Set chart options */
    const seriesArray = mappedChartData.map((series, idx) => {
        const seriesData = {
            type: 'line',
            stack: 'LineStack',
            data: series,
        };
        if (legendText) { seriesData.name = legendText[idx]; }
        return seriesData;
    });

    // Enable zoom
    if (zoom) {
        chartOptions.dataZoom = [
            {
                type: 'slider',
                orient: 'horizontal',
            },
            {
                type: 'inside',
                orient: 'horizontal',
            },
        ];
    }
    chartOptions.series = seriesArray;

    // Generate props
    const chartProps = {
        contextStyles: {
            container: styles.container,
        },
        option: chartOptions,
    };
    if (onPress) { chartProps.onPress = onPress; }
    if (testID) { chartProps.testID = testID; }

    return (
        <ChartWrapper { ...chartProps } />
    );
};

LineChart.propTypes = {
    /** Enables/disables chart animations */
    animation: PropTypes.bool,

    /** Styles for the component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,
    }),

    /** Enable display of grid lines */
    gridLines: PropTypes.bool,

    /** Enable display of horizontal grid lines */
    horizontalGridLines: PropTypes.bool,

    /** Displays the information for the charts */
    legendText: PropTypes.arrayOf(PropTypes.string),

    /** Maximum X axis value */
    maxX: PropTypes.number,

    /** Maximum Y axis value */
    maxY: PropTypes.number,

    /** Minimum X axis value */
    minX: PropTypes.number,

    /** Minimum Y axis value */
    minY: PropTypes.number,

    /**
     * Triggered on press of a symbol
     * @param {Object} itemData - Data for the symbol pressed
     */
    onPress: PropTypes.func,

    /** The data points to display for line chart */
    seriesData: PropTypes.arrayOf(PropTypes.arrayOf(PropTypes.shape({
        /** The axis line text */
        axisLabel: PropTypes.string.isRequired,

        /** Color of the line */
        color: PropTypes.string,

        /** Opacity of the line */
        opacity: PropTypes.number,

        /** Color of the symbol */
        symbolColor: PropTypes.string,

        /** Emphasis color of the symbol press/hover */
        symbolEmphasisColor: PropTypes.string,

        /** Size of the circular point */
        symbolSize: PropTypes.oneOfType([

            /** Size of the symbol in number */
            PropTypes.number,

            /** Array to represent width and height - ex: [ 10, 20 ] where width is 10 and height is 20 */
            PropTypes.arrayOf(PropTypes.number),
        ]),

        /** Value of the line */
        value: PropTypes.number.isRequired,

        /** Width of the line */
        width: PropTypes.number,
    }))).isRequired,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Title text for the chart */
    title: PropTypes.string,

    /** Show related data in a tooltip after pressing a bar */
    tooltip: PropTypes.bool,

    /** Enable display of vertical grid lines */
    verticalGridLines: PropTypes.bool,

    /** Show X axis line, ticks and labels */
    xAxis: PropTypes.bool,

    /** Name of xAxis */
    xAxisTitle: PropTypes.string,

    /** Show Y axis line, ticks and labels */
    yAxis: PropTypes.bool,

    /** Name of yAxis */
    yAxisTitle: PropTypes.string,

    /** Enable zooming in/out chart ranges */
    zoom: PropTypes.bool,
};

LineChart.defaultProps = {
    animation: true,
    contextStyles: {},
    gridLines: true,
    horizontalGridLines: true,
    tooltip: true,
    verticalGridLines: true,
    xAxis: true,
    xAxisTitle: 'X',
    yAxis: true,
    yAxisTitle: 'Y',
    zoom: true,
};

export default LineChart;

==> cv-react-library-0.1.26.tgz: package/src/components/native/LineChart/LineChart.js <==
import React from 'react';
import PropTypes from 'prop-types';
import ChartWrapper from '../ChartWrapper/ChartWrapper';

// Import styles
import getStyles from './LineChart.styles';

/**
 * A line chart displays information as a series of data points called 'markers' connected by straight line segments.
 * @see https://echarts.apache.org/examples/en/editor.html?c=line-simple
 */
const LineChart = (props) => {
    const {
        animation,
        contextStyles,
        gridLines,
        horizontalGridLines,
        legendText,
        maxX,
        maxY,
        minX,
        minY,
        onPress,
        seriesData,
        testID,
        title,
        tooltip,
        verticalGridLines,
        xAxis,
        xAxisTitle,
        yAxis,
        yAxisTitle,
        zoom,
    } = props;

    const styles = getStyles(contextStyles);

    /** Build axis options */
    const axisOptions = {
        xAxis: {
            axisTick: {
                // Move the tick from between the bars to the center of each bar
                alignWithLabel: true,
            },
            data: [],
            show: xAxis,
            splitLine: {
                // Show vertical grid lines
                show: gridLines && verticalGridLines,
            },
            type: 'category',
        },
        yAxis: {
            show: yAxis,
            splitLine: {
                // Show horizontal grid lines
                show: gridLines && horizontalGridLines,
            },
            type: 'value',
        },
    };

    // Set axis titles
    if (xAxisTitle) {
        axisOptions.xAxis.name = xAxisTitle;
        axisOptions.xAxis.nameLocation = 'center';
        axisOptions.xAxis.nameGap = 25;
    }
    if (yAxisTitle) {
        axisOptions.yAxis.name = yAxisTitle;
        axisOptions.yAxis.nameLocation = 'center';
        axisOptions.yAxis.nameGap = 30;
    }

    /** Build chart options */
    const chartOptions = {
        animation,
        backgroundColor: 'transparent',
        grid: {
            containLabel: true,
            show: true,
        },
        xAxis: axisOptions.xAxis,
        yAxis: axisOptions.yAxis,
    };

    // Set chart title
    if (title) {
        chartOptions.title = {
            text: title,
        };
    }

    // Enable tooltip
    if (tooltip) {
        chartOptions.tooltip = {
            confine: true,
        };
    }

    // Set chart legend
    if (legendText) { chartOptions.legend = { data: legendText }; }

    // Map series data prop to chart data structure
    const mappedChartData = seriesData.map((lineDataSeries) => (
        lineDataSeries.map((item) => {
            // Spread item data
            const {
                axisLabel,
                color,
                opacity,
                symbolColor,
                symbolEmphasisColor,
                symbolSize,
                value,
                width,
                ...itemRest
            } = item;

            // Build bar labels array
            if (!axisOptions.xAxis.data.find((label) => (label === axisLabel))) {
                axisOptions.xAxis.data.push(axisLabel);
            }

            // Begin minimum line detail
            const lineDetail = {
                itemStyle: {},
                lineStyle: {},
                name: axisLabel,
                value,
            };

            // Add styles for line
            if (color) {
                lineDetail.lineStyle.color = color;
            }
            if (width || width === 0) {
                lineDetail.lineStyle.width = width;
            }
            if (opacity || opacity === 0) {
                lineDetail.lineStyle.opacity = opacity;
            }

            // Add styles for circular points
            if (symbolColor) {
                lineDetail.itemStyle.color = symbolColor;
            }
            if (symbolEmphasisColor) {
                lineDetail.itemStyle.emphasis = { color: symbolEmphasisColor };
            }
            if (symbolSize || symbolSize === 0) {
                lineDetail.symbolSize = symbolSize;
            }

            // Include any item rest props overridden by details
            return {
                ...itemRest,
                ...lineDetail,
            };
        })
    ));

    // Set range parameters
    if (maxX || maxX === 0) { chartOptions.xAxis.max = maxX; }
    if (minX || minX === 0) { chartOptions.xAxis.min = minX; }
    if (maxX || minX) { chartOptions.xAxis.scale = true; }
    if (maxY || maxY === 0) { chartOptions.yAxis.max = maxY; }
    if (minY || minY === 0) { chartOptions.yAxis.min = minY; }
    if (maxY || minY) { chartOptions.yAxis.scale = true; }

    /** Set chart options */
    const seriesArray = mappedChartData.map((series, idx) => {
        const seriesData = {
            type: 'line',
            stack: 'LineStack',
            data: series,
        };
        if (legendText) { seriesData.name = legendText[idx]; }
        return seriesData;
    });

    // Enable zoom
    if (zoom) {
        chartOptions.dataZoom = [
            {
                type: 'slider',
                orient: 'horizontal',
            },
            {
                type: 'inside',
                orient: 'horizontal',
            },
        ];
    }
    chartOptions.series = seriesArray;

    // Generate props
    const chartProps = {
        contextStyles: {
            container: styles.container,
        },
        option: chartOptions,
    };
    if (onPress) { chartProps.onPress = onPress; }
    if (testID) { chartProps.testID = testID; }

    return (
        <ChartWrapper { ...chartProps } />
    );
};

LineChart.propTypes = {
    /** Enables/disables chart animations */
    animation: PropTypes.bool,

    /** Styles for the component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,
    }),

    /** Enable display of grid lines */
    gridLines: PropTypes.bool,

    /** Enable display of horizontal grid lines */
    horizontalGridLines: PropTypes.bool,

    /** Displays the information for the charts */
    legendText: PropTypes.arrayOf(PropTypes.string),

    /** Maximum X axis value */
    maxX: PropTypes.number,

    /** Maximum Y axis value */
    maxY: PropTypes.number,

    /** Minimum X axis value */
    minX: PropTypes.number,

    /** Minimum Y axis value */
    minY: PropTypes.number,

    /**
     * Triggered on press of a symbol
     * @param {Object} itemData - Data for the symbol pressed
     */
    onPress: PropTypes.func,

    /** The data points to display for line chart */
    seriesData: PropTypes.arrayOf(PropTypes.arrayOf(PropTypes.shape({
        /** The axis line text */
        axisLabel: PropTypes.string.isRequired,

        /** Color of the line */
        color: PropTypes.string,

        /** Opacity of the line */
        opacity: PropTypes.number,

        /** Color of the symbol */
        symbolColor: PropTypes.string,

        /** Emphasis color of the symbol press/hover */
        symbolEmphasisColor: PropTypes.string,

        /** Size of the circular point */
        symbolSize: PropTypes.oneOfType([

            /** Size of the symbol in number */
            PropTypes.number,

            /** Array to represent width and height - ex: [ 10, 20 ] where width is 10 and height is 20 */
            PropTypes.arrayOf(PropTypes.number),
        ]),

        /** Value of the line */
        value: PropTypes.number.isRequired,

        /** Width of the line */
        width: PropTypes.number,
    }))).isRequired,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Title text for the chart */
    title: PropTypes.string,

    /** Show related data in a tooltip after pressing a bar */
    tooltip: PropTypes.bool,

    /** Enable display of vertical grid lines */
    verticalGridLines: PropTypes.bool,

    /** Show X axis line, ticks and labels */
    xAxis: PropTypes.bool,

    /** Name of xAxis */
    xAxisTitle: PropTypes.string,

    /** Show Y axis line, ticks and labels */
    yAxis: PropTypes.bool,

    /** Name of yAxis */
    yAxisTitle: PropTypes.string,

    /** Enable zooming in/out chart ranges */
    zoom: PropTypes.bool,
};

LineChart.defaultProps = {
    animation: true,
    contextStyles: {},
    gridLines: true,
    horizontalGridLines: true,
    tooltip: true,
    verticalGridLines: true,
    xAxis: true,
    xAxisTitle: 'X',
    yAxis: true,
    yAxisTitle: 'Y',
    zoom: true,
};

export default LineChart;
